@@ -16,6 +16,7 @@
 #' - `delete_resource(..., confirm=TRUE, wait=FALSE)`: Delete an existing resource. Optionally wait for the delete to finish.
 #' - `resource_exists(...)`: Check if a resource exists.
 #' - `list_resources()`: Return a list of resource group objects for this subscription.
+#' - `do_operation(...)`: Carry out an operation. See 'Operations' for more details.
 #' - `set_tags(..., keep_existing=TRUE)`: Set the tags on this resource group. The tags can be either names or name-value pairs. To delete a tag, set it to `NULL`.
 #' - `get_tags()`: Get the tags on this resource.
 #' - `create_lock(name, level)`: Create a management lock on this resource group (which will propagate to all resources within it).
@@ -59,6 +60,15 @@
 #'
 #' To create/deploy a new resource, specify any extra parameters that the provider needs as named arguments to `create_resource()`. Like `deploy_template()`, `create_resource()` also takes an optional `wait` argument that specifies whether to wait until resource creation is complete before returning.
 #'
+#' @section Operations:
+#' The `do_operation()` method allows you to carry out arbitrary operations on the resource group. It takes the following arguments:
+#' - `op`: The operation in question, which will be appended to the URL path of the request.
+#' - `options`: A named list giving the URL query parameters.
+#' - `...`: Other named arguments passed to [call_azure_rm], and then to the appropriate call in httr. In particular, use `body` to supply the body of a PUT, POST or PATCH request, and `api_version` to set the API version.
+#' - `http_verb`: The HTTP verb as a string, one of `GET`, `PUT`, `POST`, `DELETE`, `HEAD` or `PATCH`.
+#'
+#' Consult the Azure documentation for what operations are supported.
+#'
 #' @section Role-based access control:
 #' AzureRMR implements a subset of the full RBAC functionality within Azure Active Directory. You can retrieve role definitions and add and remove role assignments, at the subscription, resource group and resource levels. See [rbac] for more information.
 #'
@@ -120,6 +130,7 @@ public=list(
     subscription=NULL,
     id=NULL,
     name=NULL,
+    type=NULL,
     location=NULL,
     managed_by=NULL,
     properties=NULL,
@@ -140,6 +151,7 @@ public=list(
         else private$init(name, parms)
 
         self$id <- parms$id
+        self$type <- parms$type
         self$location <- parms$location
         self$managed_by <- parms$managedBy
         self$properties <- parms$properties
@@ -265,6 +277,11 @@ public=list(
         else self$tags
     },
 
+    do_operation=function(..., options=list(), http_verb="GET")
+    {
+        private$rg_op(..., options=options, http_verb=http_verb)
+    },
+
     print=function(...)
     {
         cat("<Azure resource group ", self$name, ">\n", sep="")
@@ -302,7 +319,7 @@ private=list(
     validate_parms=function(parms)
     {
         required_names <- c("location", "name")
-        optional_names <- c("id", "managedBy", "tags", "properties")
+        optional_names <- c("id", "managedBy", "tags", "properties", "type")
         validate_object_names(names(parms), required_names, optional_names)
     },
 
