@@ -92,8 +92,16 @@ delete_confirmed <- function(confirm, name, type, quote_name=TRUE)
         return(TRUE)
 
     msg <- if(quote_name)
-        sprintf("Do you really want to delete the %s '%s'? (y/N) ", type, name)
-    else sprintf("Do you really want to delete the %s %s? (y/N) ", type, name)
-    yn <- readline(msg)
-    return(tolower(substr(yn, 1, 1)) == "y")
+        sprintf("Do you really want to delete the %s '%s'?", type, name)
+    else sprintf("Do you really want to delete the %s %s?", type, name)
+    ok <- if(getRversion() < numeric_version("3.5.0"))
+    {
+        msg <- paste(msg, "(yes/No/cancel) ")
+        yn <- readline(msg)
+        if(nchar(yn) == 0)
+            FALSE
+        else tolower(substr(yn, 1, 1)) == "y"
+    }
+    else utils::askYesNo(msg, FALSE)
+    isTRUE(ok)
 }
